summaryrefslogtreecommitdiff
path: root/src/gui
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui')
-rw-r--r--src/gui/sdlinput.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/gui/sdlinput.cpp b/src/gui/sdlinput.cpp
index b6fabd8a5..c4c7c9741 100644
--- a/src/gui/sdlinput.cpp
+++ b/src/gui/sdlinput.cpp
@@ -139,7 +139,7 @@ void SDLInput::pushInput(const SDL_Event &event)
MouseInput mouseInput;
#ifdef __SWITCH__
// send an escape/cancel key on keyboard dismiss event
bool visible = SDL_GetEventState(SDL_TEXTINPUT) == SDL_ENABLE;
if(visible)
{
@@ -147,7 +147,7 @@ void SDLInput::pushInput(const SDL_Event &event)
}
else if(!keyboardClosed)
{
- simulateKey(KeyValue::ESCAPE, InputAction::GUI_CANCEL);
+ simulateKey(KeyValue::ENTER, InputAction::GUI_SELECT2);
keyboardClosed = true;
}
#endif
@@ -139,7 +139,7 @@ void SDLInput::pushInput(const SDL_Event &event)
MouseInput mouseInput;
#ifdef __SWITCH__
- // send an escape/cancel key on keyboard dismiss event
+ // send an enter/select key on keyboard dismiss event
bool visible = SDL_GetEventState(SDL_TEXTINPUT) == SDL_ENABLE;
if(visible)